CachedTextRepresentation
========================

.. currentmodule:: pykeen.nn.representation

.. autoclass:: CachedTextRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CachedTextRepresentation.from_triples_factory

   .. rubric:: Methods Documentation

   .. automethod:: from_triples_factory
